#!/bin/sh
#
# postfix      This shell script takes care of starting and stopping
#               postfix.
#
# chkconfig: 2345 80 30
# description: Postfix is a Mail Transport Agent, which is the program \
#              that moves mail from one machine to another.
# processname: postfix
# config: /etc/postfix/
# pidfile: /var/run/postfix.pid

# Hacked by jam 25 Feb 99.  Mostly s/sendmail/postfix/g :-)

# Source function library.
. /etc/init.d/functions

# Source networking configuration.
. /etc/default/network

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

[ -f /usr/sbin/postfix ] || exit 0

RETVAL=0

# See how we were called.
case "$1" in
  start)
	# Start daemons.
	echo -n "               Postfix Mail Server"
	daemon /usr/sbin/postfix start
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/postfix
	;;
  stop)
	# Stop daemons.
	echo -n "               Postfix Mail Server"
	init_term "STOPPING"

	if [ -f /var/lock/subsys/postfix ]; then
		/usr/sbin/postfix stop > /dev/null 2>&1
		RETVAL=$?
		if [ $RETVAL -eq 0 ] 
		then
			rm -f /var/lock/subsys/postfix
			success postfix
		else
			failure postfix
		fi
	fi

	echo
	;;
  restart)
	$0 stop
	$0 start
	;;
  reload)
	/usr/sbin/postfix reload
        exit $?
	;;
  abort)
	/usr/sbin/postfix abort
	rm -f /var/lock/subsys/postfix
        exit $?
	;;
  flush)
	/usr/sbin/postfix flush
        exit $?
	;;
  check)
	/usr/sbin/postfix check
        exit $?
	;;
  *)
	echo "Usage: postfix {start|stop|restart|reload|abort|flush|check}"
	exit 1
esac

exit $RETVAL
